group

package
v0.0.0-...-47c65c1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 18, 2020 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func By24Hour

func By24Hour(photoList []Image) map[time.Time][]Image

By24Hour raggruppa per periodi di 24 ore, partendo dalla prima occorrenza fino al massimo alle ore 6 del giorno dopo se non ci sono periodi senza file di più di 3 ore

func BySolarDay

func BySolarDay(photoList []Image) map[time.Time][]Image

BySolarDay raggruppa per giorno solare

Types

This section is empty.

Jump to